@@ -13,13 +13,14 @@
 # limitations under the License.
 
 from notebook.utils import url_path_join
-from notebook.base.handlers import APIHandler
+from notebook.base.handlers import APIHandler, IPythonHandler
 
 import json
 from tornado import web
 from .environment import *
 import beakerx
 import tornado
+import os
 
 
 class SettingsHandler(APIHandler):
@@ -53,11 +54,25 @@ class VersionHandler(APIHandler):
         self.finish(json.dumps(data))
 
 
+class JavaDoc(web.StaticFileHandler, IPythonHandler):
+    def initialize(self):
+        beakerx_path = os.path.dirname(beakerx.__file__)
+        web.StaticFileHandler.initialize(self, path=os.path.join(beakerx_path, 'javadoc'))
+
+    @web.authenticated
+    def get(self, path):
+        self.set_header('Content-Type', 'text/html')
+        return web.StaticFileHandler.get(self, path)
+
+
 def load_jupyter_server_extension(nbapp):
     web_app = nbapp.web_app
     host_pattern = '.*$'
     settings_route_pattern = url_path_join(web_app.settings['base_url'], '/beakerx', '/settings')
     version_route_pattern = url_path_join(web_app.settings['base_url'], '/beakerx', '/version')
+    javadoc_route_pattern = url_path_join(web_app.settings['base_url'], '/beakerx', '/javadoc/(.*)')
     web_app.add_handlers(host_pattern, [(settings_route_pattern, SettingsHandler)])
     web_app.add_handlers(host_pattern, [(version_route_pattern, VersionHandler)])
+    web_app.add_handlers(host_pattern, [(javadoc_route_pattern, JavaDoc)])
+
     nbapp.log.info("[beakerx] enabled")
